# -*- coding: utf-8 -*-
"""
"""

__title__ = "SweetRPG Web Core"
__description__ = "Common code for Web frontend microservice applications"
__url__ = "https://github.com/sweetrpg/web-core"
__version__ = "0.0.63"
__build__ = 0x000000
__author__ = "Paul Schifferer"
__author_email__ = "dm@sweetrpg.com"
__license__ = "MIT"
__copyright__ = "Copyright 2021 SweetRPG"
__cake__ = "\u2728 \U0001f370 \u2728"
